@@ -24,16 +24,21 @@
 //
 //     You should have received a copy of the GNU General Public License
 //     along with this program; see the file COPYING.  If not, please obtain
-//     a copy from http://www.gnu.org/copyleft/gpl.html
+//     a copy from https://www.gnu.org/copyleft/gpl.html
 //
 /////////////////////////////////////////////////////////////////////////////
 
 #include "kio_smb.h"
-#include "kio_smb_internal.h"
+#include "smburl.h"
 #include <QCoreApplication>
 #include <QVersionNumber>
 
-Q_LOGGING_CATEGORY(KIO_SMB, "kio_smb")
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.smb" FILE "smb.json")
+};
 
 bool needsEEXISTWorkaround()
 {
@@ -46,68 +51,51 @@ bool needsEEXISTWorkaround()
      *
      * Upstream bug report: https://bugzilla.samba.org/show_bug.cgi?id=13050
      */
-    static const QVersionNumber firstBrokenVer{4, 7, 0};
-    static const QVersionNumber lastBrokenVer{4, 7, 6};
+    static const QVersionNumber firstBrokenVer {4, 7, 0};
+    static const QVersionNumber lastBrokenVer {4, 7, 6};
 
     const QVersionNumber currentVer = QVersionNumber::fromString(smbc_version());
-    qCDebug(KIO_SMB) << "Using libsmbclient library version" << currentVer;
+    qCDebug(KIO_SMB_LOG) << "Using libsmbclient library version" << currentVer;
 
     if (currentVer >= firstBrokenVer && currentVer <= lastBrokenVer) {
-        qCDebug(KIO_SMB) << "Detected broken libsmbclient version" << currentVer;
+        qCDebug(KIO_SMB_LOG) << "Detected broken libsmbclient version" << currentVer;
         return true;
     }
 
     return false;
 }
 
-//===========================================================================
-SMBSlave::SMBSlave(const QByteArray& pool, const QByteArray& app)
-    : SlaveBase( "smb", pool, app ),
-      m_openFd(-1),
-      m_enableEEXISTWorkaround(needsEEXISTWorkaround())
+SMBSlave::SMBSlave(const QByteArray &pool, const QByteArray &app)
+    : SlaveBase("smb", pool, app)
+    , m_openFd(-1)
+    , m_enableEEXISTWorkaround(needsEEXISTWorkaround())
 {
     m_initialized_smbc = false;
 
-    //read in the default workgroup info...
+    // read in the default workgroup info...
     reparseConfiguration();
 
-    //initialize the library...
+    // initialize the library...
     auth_initialize_smbc();
 }
 
+SMBSlave::~SMBSlave() = default;
 
-//===========================================================================
-SMBSlave::~SMBSlave()
+void SMBSlave::virtual_hook(int id, void *data)
 {
-}
-
-void SMBSlave::virtual_hook(int id, void *data) {
-    switch(id) {
+    switch (id) {
     case SlaveBase::GetFileSystemFreeSpace: {
         QUrl *url = static_cast<QUrl *>(data);
         fileSystemFreeSpace(*url);
     } break;
+    case SlaveBase::Truncate: {
+        auto length = static_cast<KIO::filesize_t *>(data);
+        truncate(*length);
+    } break;
     default: {
         SlaveBase::virtual_hook(id, data);
     } break;
     }
 }
 
-//===========================================================================
-int Q_DECL_EXPORT kdemain( int argc, char **argv )
-{
-    QCoreApplication app(argc, argv);
-    if( argc != 4 )
-    {
-        qCDebug(KIO_SMB) << "Usage: kio_smb protocol domain-socket1 domain-socket2"
-                  << endl;
-        return -1;
-    }
-
-    SMBSlave slave( argv[2], argv[3] );
-
-    slave.dispatchLoop();
-
-    return 0;
-}
-
+#include "kio_smb.moc"
