@@ -130,7 +130,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
 
 
     if (argc != 4) {
-        qCritical() << "Usage: kio_thumbnail protocol domain-socket1 domain-socket2" << endl;
+        qCritical() << "Usage: kio_thumbnail protocol domain-socket1 domain-socket2";
         exit(-1);
     }
 
@@ -176,7 +176,7 @@ void ThumbnailProtocol::get(const QUrl &url)
             return;
         } else if (!info.isReadable()) {
             // The file is not readable!
-            error(KIO::ERR_COULD_NOT_READ,url.path());
+            error(KIO::ERR_CANNOT_READ,url.path());
             return;
         }
 
